==> nextcloud-11.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/zh_TW.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "無效的儲存空間",
    "Unknown error" : "未知的錯誤",
    "Files" : "檔案",
    "All files" : "所有檔案",
    "Recent" : "近期",
    "File could not be found" : "找不到檔案",
    "Home" : "家目錄",
    "Close" : " 關閉",
    "Favorites" : "最愛",
    "Could not create folder \"{dir}\"" : "無法建立資料夾 \"{dir}\"",
    "Upload cancelled." : "上傳已取消",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "因為 {filename} 是個目錄或是大小為零，所以無法上傳",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空間不足，你正要上傳 {size1} 可是只剩下 {size2}",
    "Uploading..." : "上傳中…",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中的 {loadedSize} ({bitrate})",
    "Actions" : "動作",
    "Download" : "下載",
    "Rename" : "重新命名",
    "Delete" : "刪除",
    "Disconnect storage" : "斷開儲存空間連接",
    "Unshare" : "取消分享",
    "Details" : "詳細資料",
    "Select" : "選擇",
    "Pending" : "等候中",
    "Unable to determine date" : "無法確定日期",
    "This operation is forbidden" : "此動作被禁止",
    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法存取，請檢查伺服器記錄檔或聯絡管理員",
    "Could not move \"{file}\", target exists" : "無法移動 \"{file}\"，目標已經存在",
    "Could not move \"{file}\"" : "無法移動 \"{file}\"",
    "{newName} already exists" : "{newName} 已經存在",
    "Could not rename \"{fileName}\", it does not exist any more" : "無法命名檔案 \"{fileName}\"，因為此檔案已經不存在",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱 \"{targetName}\" 在這資料夾 \"{dir}\" 已經被使用。請重新選擇不同的名稱",
    "Could not rename \"{fileName}\"" : "無法重新命名 \"{fileName}\"",
    "Could not create file \"{file}\"" : "無法建立檔案 \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "無法建立檔案 \"{file}\"，因為此檔案已存在",
    "Could not create folder \"{dir}\" because it already exists" : "無法建立資料夾 \"{dir}\"，因為此資料夾已存在",
    "Error deleting file \"{fileName}\"." : "刪除 \"{fileName}\" 出錯",
    "Name" : "名稱",
    "Size" : "大小",
    "Modified" : "修改時間",
    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
    "_%n file_::_%n files_" : ["%n 個檔案"],
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "_including %n hidden_::_including %n hidden_" : ["包含 %n 隱藏檔"],
    "You don’t have permission to upload or create files here" : "您沒有權限在這裡上傳或建立檔案",
    "_Uploading %n file_::_Uploading %n files_" : ["正在上傳 %n 個檔案"],
    "New" : "新增",
    "\"{name}\" is an invalid file name." : "{name} 是無效的檔名",
    "File name cannot be empty." : "檔名不能為空",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的儲存空間已滿，沒有辦法再更新或是同步檔案！",
    "Your storage is full, files can not be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的儲存空間快要滿了 ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "您的儲存空間快要滿了 ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["符合「{filter}」"],
    "View in folder" : "在資料夾中檢視",
    "Path" : "路徑",
    "_%n byte_::_%n bytes_" : ["%n 位元組"],
    "Favorited" : "已加入最愛",
    "Favorite" : "我的最愛",
    "Folder" : "資料夾",
    "New folder" : "新資料夾",
    "Upload" : "上傳",
    "An error occurred while trying to update the tags" : "更新標籤時發生錯誤",
    "A new file or folder has been <strong>created</strong>" : "新的檔案或目錄已被 <strong>建立</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "僅顯示<strong>已加星號的檔案</strong>的動態通知<em>（僅限訊息串）</em>",
    "Upload (max. %s)" : "上傳（至多 %s）",
    "File handling" : "檔案處理",
    "Maximum upload size" : "上傳限制",
    "max. possible: " : "最大允許：",
    "Save" : "儲存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "如果使用 PHP-FPM ，此設定值需要5分鐘左右才會生效。",
    "Missing permissions to edit from here." : "您沒有在此編輯的權限",
    "Settings" : "設定",
    "Show hidden files" : "顯示隱藏檔",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "使用這個位址來<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">使用 WebDAV 存取檔案</a>",
    "No files in here" : "沒有任何檔案",
    "Upload some content or sync with your devices!" : "在您的裝置中同步或上傳一些內容",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Select all" : "全選",
    "Upload too large" : "上傳過大",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您試圖上傳的檔案大小超過伺服器的限制",
    "No favorites" : "沒有最愛",
    "Files and folders you mark as favorite will show up here" : "您標記為最愛的檔案與資料夾將會顯示在這裡",
    "Text file" : "文字檔",
    "New text file.txt" : "新文字檔.txt",
    "Storage not available" : "無法存取儲存空間",
    "Unable to set upload directory." : "無法設定上傳目錄",
    "Invalid Token" : "無效的 token",
    "No file was uploaded. Unknown error" : "沒有檔案被上傳，原因未知",
    "There is no error, the file uploaded with success" : "一切都順利，檔案上傳成功",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "上傳的檔案大小超過 php.ini 當中 upload_max_filesize 參數的設定：",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上傳的檔案大小超過 HTML 表單中 MAX_FILE_SIZE 的限制",
    "The uploaded file was only partially uploaded" : "只有檔案的一部分被上傳",
    "No file was uploaded" : "沒有檔案被上傳",
    "Missing a temporary folder" : "找不到暫存資料夾",
    "Failed to write to disk" : "寫入硬碟失敗",
    "Not enough storage available" : "儲存空間不足",
    "The target folder has been moved or deleted." : "目標資料夾已經被搬移或刪除",
    "Upload failed. Could not find uploaded file" : "上傳失敗，找不到上傳的檔案",
    "Upload failed. Could not get file info." : "上傳失敗，無法取得檔案資訊",
    "Invalid directory." : "無效的資料夾",
    "Total file size {size1} exceeds upload limit {size2}" : "檔案大小總和 {size1} 超過上傳限制 {size2}",
    "Error uploading file \"{fileName}\": {message}" : "上傳檔案 \"{fileName}\" 發生錯誤：{message}",
    "Could not get result from server." : "無法從伺服器取回結果",
    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "剩下 {hours}:{minutes}:{seconds} 小時",
    "{hours}:{minutes}h" : "{hours}:{minutes} 小時",
    "{minutes}:{seconds} minute{plural_s} left" : "剩下 {minutes}:{seconds} 分鐘",
    "{minutes}:{seconds}m" : "{minutes}:{seconds} 分",
    "{seconds} second{plural_s} left" : "剩下 {seconds} 秒",
    "{seconds}s" : "{seconds} 秒",
    "Any moment now..." : "即將完成…",
    "Soon..." : "即將完成…",
    "File upload is in progress. Leaving the page now will cancel the upload." : "檔案上傳中，離開此頁面將會取消上傳",
    "No entries in this folder match '{filter}'" : "在此資料夾中沒有項目與 '{filter}' 相符",
    "Local link" : "本地連結",
    "{newname} already exists" : "{newname} 已經存在",
    "A file or folder has been <strong>changed</strong>" : "檔案或目錄已被 <strong>變更</strong>",
    "A file or folder has been <strong>deleted</strong>" : "檔案或目錄已被 <strong>刪除</strong>",
    "A file or folder has been <strong>restored</strong>" : "檔案或目錄已被 <strong>恢復</strong>",
    "You created %1$s" : "您建立了 %1$s",
    "%2$s created %1$s" : "%2$s 已建立 %1$s",
    "%1$s was created in a public folder" : "%1$s 已建立於公開的目錄",
    "You changed %1$s" : "您變更了 %1$s",
    "%2$s changed %1$s" : "%2$s 已變更了 %1$s",
    "You deleted %1$s" : "您刪除了 %1$s",
    "%2$s deleted %1$s" : "%2$s 已刪除 %1$s",
    "You restored %1$s" : "您還原了 %1$s",
    "%2$s restored %1$s" : "%2$s 還原了 %1$s",
    "Changed by %2$s" : "由 %2$s 改動",
    "Deleted by %2$s" : "由 %2$s 刪除",
    "Restored by %2$s" : "由 %2$s 還原"
},
"nplurals=1; plural=0;");

==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/zh_TW.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "空間暫時無法使用",
    "Storage invalid" : "無效的儲存空間",
    "Unknown error" : "未知的錯誤",
    "All files" : "所有檔案",
    "Recent" : "近期",
    "File could not be found" : "找不到檔案",
    "Home" : "家目錄",
    "Close" : " 關閉",
    "Favorites" : "最愛",
    "Could not create folder \"{dir}\"" : "無法建立資料夾 \"{dir}\"",
    "Upload cancelled." : "上傳已取消",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "因為 {filename} 是個目錄或是大小為零，所以無法上傳",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空間不足，你正要上傳 {size1} 可是只剩下 {size2}",
    "Target folder \"{dir}\" does not exist any more" : "資料夾 \"{dir}\" 不存在",
    "Not enough free space" : "空間不足",
    "Uploading..." : "上傳中…",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中的 {loadedSize} ({bitrate})",
    "Actions" : "動作",
    "Download" : "下載",
    "Rename" : "重新命名",
    "Move" : "移動",
    "Target folder" : "目標資料夾",
    "Delete" : "刪除",
    "Disconnect storage" : "斷開儲存空間連接",
    "Unshare" : "取消分享",
    "Could not load info for file \"{file}\"" : "無法讀取 \"{file}\" 的詳細資料",
    "Files" : "檔案",
    "Details" : "詳細資料",
    "Select" : "選擇",
    "Pending" : "等候中",
    "Unable to determine date" : "無法確定日期",
    "This operation is forbidden" : "此動作被禁止",
    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法存取，請檢查伺服器記錄檔或聯絡管理員",
    "Could not move \"{file}\", target exists" : "無法移動 \"{file}\"，目標已經存在",
    "Could not move \"{file}\"" : "無法移動 \"{file}\"",
    "{newName} already exists" : "{newName} 已經存在",
    "Could not rename \"{fileName}\", it does not exist any more" : "無法命名檔案 \"{fileName}\"，因為此檔案已經不存在",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱 \"{targetName}\" 在這資料夾 \"{dir}\" 已經被使用。請重新選擇不同的名稱",
    "Could not rename \"{fileName}\"" : "無法重新命名 \"{fileName}\"",
    "Could not create file \"{file}\"" : "無法建立檔案 \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "無法建立檔案 \"{file}\"，因為此檔案已存在",
    "Could not create folder \"{dir}\" because it already exists" : "無法建立資料夾 \"{dir}\"，因為此資料夾已存在",
    "Error deleting file \"{fileName}\"." : "刪除 \"{fileName}\" 出錯",
    "No search results in other folders for {tag}{filter}{endtag}" : "在其它資料夾中沒有找到 {tag}{filter}{endtag}",
    "Name" : "名稱",
    "Size" : "大小",
    "Modified" : "修改時間",
    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
    "_%n file_::_%n files_" : ["%n 個檔案"],
    "{dirs} and {files}" : "{dirs} 和 {files}",
    "_including %n hidden_::_including %n hidden_" : ["包含 %n 隱藏檔"],
    "You don’t have permission to upload or create files here" : "您沒有權限在這裡上傳或建立檔案",
    "_Uploading %n file_::_Uploading %n files_" : ["正在上傳 %n 個檔案"],
    "New" : "新增",
    "\"{name}\" is an invalid file name." : "{name} 是無效的檔名",
    "File name cannot be empty." : "檔名不能為空",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" 並不是經允許的檔案類型",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "{owner} 的儲存空間已滿，沒有辦法再更新或是同步檔案！",
    "Your storage is full, files can not be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "{owner} 的儲存空間快要滿了 ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "您的儲存空間快要滿了 ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["符合「{filter}」"],
    "View in folder" : "在資料夾中檢視",
    "Copied!" : "已複製",
    "Copy direct link (only works for users who have access to this file/folder)" : "複製直接連結(只對能存取的用戶有用)",
    "Path" : "路徑",
    "_%n byte_::_%n bytes_" : ["%n 位元組"],
    "Favorited" : "已加入最愛",
    "Favorite" : "我的最愛",
    "New folder" : "新資料夾",
    "Upload file" : "上傳檔案",
    "An error occurred while trying to update the tags" : "更新標籤時發生錯誤",
    "Added to favorites" : "添加到最愛",
    "Removed from favorites" : "從最愛移除",
    "You added {file} to your favorites" : "你已添加 {file} 至最愛",
    "You removed {file} from your favorites" : "你已移除 {file} 從最愛",
    "File changes" : "檔案更動",
    "Created by {user}" : "由 {user} 建立",
    "Changed by {user}" : "由 {user} 改動",
    "Deleted by {user}" : "由 {user} 刪除",
    "Restored by {user}" : "由 {user} 還原",
    "Renamed by {user}" : "由 {user} 重新命名",
    "Moved by {user}" : "由 {user} 移動",
    "\"remote user\"" : "「遠端用戶」",
    "You created {file}" : "您建立了 {file}",
    "{user} created {file}" : "{user} 建立了 {file}",
    "{file} was created in a public folder" : "{file} 已建立於共享資料夾",
    "You changed {file}" : "您變更了 {file}",
    "{user} changed {file}" : "{user} 變更了 {file}",
    "You deleted {file}" : "您刪除了 {file}",
    "{user} deleted {file}" : "{user} 刪除了 {file}",
    "You restored {file}" : "您還原了 {file}",
    "{user} restored {file}" : "{user} 還原了 {file}",
    "You renamed {oldfile} to {newfile}" : "您變更 {oldfile} 為 {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} 變更 {oldfile} 為 {newfile}",
    "You moved {oldfile} to {newfile}" : "您移動 {oldfile} 到 {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} 移動 {oldfile} 到 {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "檔案已被新增或移除從 <strong>最愛</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "檔案或目錄已被 <strong>更動</strong> 或 <strong>改名</strong>",
    "A new file or folder has been <strong>created</strong>" : "新的檔案或目錄已被 <strong>建立</strong>",
    "A file or folder has been <strong>deleted</strong>" : "檔案或目錄已被 <strong>刪除</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "僅顯示<strong>已加星號的檔案</strong>的動態通知<em>（僅限訊息串）</em>",
    "A file or folder has been <strong>restored</strong>" : "檔案或目錄已被 <strong>恢復</strong>",
    "Unlimited" : "無限制",
    "Upload (max. %s)" : "上傳（至多 %s）",
    "File handling" : "檔案處理",
    "Maximum upload size" : "上傳限制",
    "max. possible: " : "最大允許：",
    "Save" : "儲存",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "如果使用 PHP-FPM ，此設定值需要5分鐘左右才會生效。",
    "Missing permissions to edit from here." : "您沒有在此編輯的權限",
    "%s of %s used" : "在 %s 中使用了 %s",
    "%s used" : "%s已使用",
    "Settings" : "設定",
    "Show hidden files" : "顯示隱藏檔",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "使用這個位址來<a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">使用 WebDAV 存取檔案</a>",
    "No files in here" : "沒有任何檔案",
    "Upload some content or sync with your devices!" : "在您的裝置中同步或上傳一些內容",
    "No entries found in this folder" : "在此資料夾中沒有任何項目",
    "Select all" : "全選",
    "Upload too large" : "上傳過大",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您試圖上傳的檔案大小超過伺服器的限制",
    "No favorites yet" : "尚無最愛",
    "Files and folders you mark as favorite will show up here" : "您標記為最愛的檔案與資料夾將會顯示在這裡",
    "Shared with you" : "與您分享",
    "Shared with others" : "與其他人分享",
    "Shared by link" : "由連結分享",
    "Tags" : "標籤",
    "Deleted files" : "回收桶",
    "Text file" : "文字檔",
    "New text file.txt" : "新文字檔.txt",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["剩下 {hours}:{minutes}:{seconds} 小時"],
    "{hours}:{minutes}h" : "{hours}:{minutes} 小時",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["剩下 {minutes}:{seconds} 分鐘"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds} 分",
    "_{seconds} second left_::_{seconds} seconds left_" : ["剩下 {seconds} 秒"],
    "{seconds}s" : "{seconds} 秒",
    "Any moment now..." : "即將完成…",
    "Soon..." : "即將完成…",
    "File upload is in progress. Leaving the page now will cancel the upload." : "檔案上傳中，離開此頁面將會取消上傳",
    "Copy local link" : "複製本地連結",
    "Folder" : "資料夾",
    "Upload" : "上傳",
    "A new file or folder has been <strong>deleted</strong>" : "檔案或目錄已被 <strong>刪除</strong>",
    "A new file or folder has been <strong>restored</strong>" : "檔案或目錄已被 <strong>恢復</strong>",
    "No favorites" : "沒有最愛"
},
"nplurals=1; plural=0;");
